arcbox-computer 0.8.1

Agent-computer domain layer for ArcBox: transport-free sandbox protocols
docs.rs failed to build arcbox-computer-0.8.1
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.